@@ -183,14 +183,6 @@ class TreeEditor(admin.ModelAdmin):
                 self.list_display[0] = 'indented_short_title'
         self.list_display_links = ('indented_short_title',)
 
-
-        print self.change_list_template
-
-        # opts = self.model._meta
-        # self.change_list_template = [
-        #     ,
-        # ]
-
     def editable(self, item):
         return getattr(item, 'feincms_editable', True)
 
